Stan Math Library: stan::math::dummy Struct Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

stan::math::dummy Struct Reference

Empty struct for use in boost::condtional<is_constant_struct<T1>::value, T1, dummy>::type as false condtion for safe indexing. More...

`#include <container_view.hpp>`

## Detailed Description

Empty struct for use in boost::condtional<is_constant_struct<T1>::value, T1, dummy>::type as false condtion for safe indexing.

Definition at line 53 of file container_view.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/meta/container_view.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.